aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/org/apache/fop/fo/pagination/PageSequenceMaster.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/java/org/apache/fop/fo/pagination/PageSequenceMaster.java')
-rw-r--r--src/java/org/apache/fop/fo/pagination/PageSequenceMaster.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/java/org/apache/fop/fo/pagination/PageSequenceMaster.java b/src/java/org/apache/fop/fo/pagination/PageSequenceMaster.java
index 4258a1139..b6c8c0f6b 100644
--- a/src/java/org/apache/fop/fo/pagination/PageSequenceMaster.java
+++ b/src/java/org/apache/fop/fo/pagination/PageSequenceMaster.java
@@ -189,14 +189,14 @@ public class PageSequenceMaster extends FObj {
* @param isOnlyPage True if the next page is the only page
* @param isBlankPage True if the next page is blank
* @return the requested page master
* @throws FOPException if there's a problem determining the next page master
*/
public SimplePageMaster getNextSimplePageMaster(boolean isOddPage,
boolean isFirstPage,
boolean isLastPage,
boolean isOnlyPage,
boolean isBlankPage)
- throws FOPException {
+ throws PageProductionException {
if (currentSubSequence == null) {
currentSubSequence = getNextSubSequence();
if (currentSubSequence == null) {
@@ -189,14 +189,14 @@ public class PageSequenceMaster extends FObj {
* @param isBlankPage True if the next page is blank
* @return the requested page master
- * @throws FOPException if there's a problem determining the next page master
+ * @throws PageProductionException if there's a problem determining the next page master
*/
public SimplePageMaster getNextSimplePageMaster(boolean isOddPage,